# ChemBot


[Documentation](https://dylanwal.github.io/ChemBot/)


In Lab:
* Email - Exhaust
* solder LED driver
    * Violet (425+-10 nm, 2.75 V (3.5 V_max), 1200 mA_max)
    * Blue (475+-20 nm, 2.84 V (3.5 V_max), 1000 mA_max)
    * Cyan (500+-30 nm, 3.05 V (3.5 V_max), 1000 mA_max)
    * GRN  (530+-30 nm, 3.05 V (3.5 V_max), 1000 mA_max)
    * Mint (550+80-40 nm, 2.75 V (3.5 V_max), 1200 mA_max)
    * Deep Red (665+-20 nm, 2.05 V (2.3 V_max), 700 mA_max)
  
    Take off bother 0.3 resistors
    * 300 mA  ()= 0
    * 600 mA () = 2 boards
    * 770 mA (0.13 ohm) = 1 board (most here) 
    * 1 A (0.1 ohm) = 1 board
* solder small LED
  * 200 oC pre-heat (1 min)  
  * 260 oC max (20 sec)

* Valves
* Build light setup 
* phase sensors
* UV Vis CTA/Cat


Code:
* small syringe pump
* large syringe pump
* thermoisters
* chiller 
* bubble detect
* valve
* redo arm with pico
* redo frac collect with pico  
* build in cript
* build gui

Other:
* finish lit
* more annotations
* check out other NLP
* write CRIPT
